ButtonTheme class

Constructors

ButtonTheme({Color color = const Color.fromRGBO(45, 50, 59, 1.0), Radius borderRadius = const Radius.circular(3.0), List<BoxShadow> shadow = const [BoxShadow(blurRadius: 2.0, color: Color.fromRGBO(0, 0, 0, 0.2), offset: Offset(0.0, 1.0))], Color buttonPressedTint = const Color.fromRGBO(0, 0, 0, 0.1), Color buttonHoveredTint = const Color.fromRGBO(255, 255, 255, 0.05), Offset buttonPressedOffset = const Offset(0.0, 0.5), Color separatorColor = const Color.fromRGBO(0, 0, 0, 0.2), double separatorWidth = 1.2, IconThemeData disabledButtonIconTheme = const IconThemeData(color: Color.fromRGBO(255, 255, 255, 0.25), size: 18.5), IconThemeData pressedButtonIconTheme = const IconThemeData(color: Color.fromRGBO(255, 255, 255, 0.5), size: 18.5), IconThemeData iconTheme = const IconThemeData(color: Color.fromRGBO(255, 255, 255, 0.9), size: 18.5), TextStyle disabledButtonTextStyle = const TextStyle(color: Color.fromRGBO(255, 255, 255, 0.25)), TextStyle pressedButtonTextStyle = const TextStyle(color: Color.fromRGBO(255, 255, 255, 0.5)), TextStyle textStyle = const TextStyle(color: Color.fromRGBO(255, 255, 255, 0.9)), BoxBorder boxBorder = const GradientBoxBorder(gradient: LinearGradient(colors: [Color.fromRGBO(255, 255, 255, 0.1), Colors.transparent, Colors.transparent], begin: Alignment.topCenter, end: Alignment.bottomCenter), width: 1.0)})
const

Properties

borderRadius → Radius
The buttons' border radius.
final
boxBorder → BoxBorder
The border of the individual button inside a button row.
final
buttonHoveredTint → Color
The color to tint the button with when it is hovered over.
final
buttonPressedOffset → Offset
The offset of the button when it is pressed.
final
buttonPressedTint → Color
The color to tint the button with when it is pressed.
final
color → Color
The buttons' color.
final
disabledButtonIconTheme → IconThemeData
The icon theme of a disabled button.
final
disabledButtonTextStyle → TextStyle
The text style of a disabled button.
final
hashCode → int
The hash code for this object.
no setterinherited
iconTheme → IconThemeData
The icon theme of an enabled, unpressed button.
final
pressedButtonIconTheme → IconThemeData
The icon theme of a pressed button.
final
pressedButtonTextStyle → TextStyle
The text style of a pressed button.
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
separatorColor → Color
The color of the line that separates two buttons within a button row.
final
separatorWidth → double
The width of the line that separates two buttons within a button row.
final
shadow → List<BoxShadow>
The buttons' shadow(s).
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
textStyle → TextStyle
The text style of an enabled, unpressed button.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited