CloseButtonTheme class

Constructors

CloseButtonTheme({BoxDecoration hoverDecoration = const BoxDecoration(color: Color.fromRGBO(255, 255, 255, 0.2), borderRadius: BorderRadius.all(Radius.circular(1024.0))), Color color = const Color.fromRGBO(255, 255, 255, 0.9)})
const

Properties

color → Color
The close button's color.
final
hashCode → int
The hash code for this object.
no setterinherited
hoverDecoration → BoxDecoration
The box decoration of a close button's hover effect.
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited