DialogTheme class

Constructors

DialogTheme({Color backgroundColor = const Color.fromRGBO(38, 39, 47, 0.75), Color barrierColor = const Color.fromRGBO(0, 0, 0, 0.35), Duration openCloseAnimationDuration = const Duration(milliseconds: 150), Curve openCloseAnimationCurve = Curves.easeInOutSine, Offset openCloseAnimationOffset = const Offset(0.0, -16.0), Alignment alignment = Alignment.center, double blurRadius = 16.0, BorderRadius borderRadius = const BorderRadius.all(Radius.circular(5.0)), Color borderColor = const Color.fromRGBO(255, 255, 255, 0.025), List<BoxShadow> shadow = const [BoxShadow(blurRadius: 8.0, color: Color.fromRGBO(0, 0, 0, 0.25), spreadRadius: 4.0, offset: Offset(0.0, 4.0))], EdgeInsets padding = const EdgeInsets.all(8.0), double actionButtonHeight = 32.0, Color actionButtonSectionBackgroundColor = const Color.fromRGBO(16, 18, 21, 0.5), double baseActionButtonRowWidth = 192.0, double customDialogActionButtonWidthAddition = 32.0, double distanceBetweenContentAndActionButtons = 8.0})
const

Properties

actionButtonHeight → double
The height of the buttons in the dialog box's action button row.
final
actionButtonSectionBackgroundColor → Color
The background color of the section in which the dialog's action buttons are located.
final
alignment → Alignment
The alignment of a dialog box.
final
backgroundColor → Color
A dialog's background color.
final
barrierColor → Color
The color of a dialog's barrier.
final
baseActionButtonRowWidth → double
The base width of a dialog's action button row, upon which customDialogActionButtonWidthAddition gets added for each action button.
final
blurRadius → double
The blur radius of a dialog's backdrop effect.
final
borderColor → Color
The border color of a dialog box.
final
borderRadius → BorderRadius
The border radius of a dialog box.
final
customDialogActionButtonWidthAddition → double
The amount to add to the default action button row width for each action button.
final
distanceBetweenContentAndActionButtons → double
The distance between the dialog's content and its action button row.
final
hashCode → int
The hash code for this object.
no setterinherited
openCloseAnimationCurve → Curve
The animation curve of a dialog's open/close animation.
final
openCloseAnimationDuration → Duration
The duration of a dialog's open/close animation.
final
openCloseAnimationOffset → Offset
The offset of the dialog's open/close animation.
final
padding → EdgeInsets
The padding of a dialog box.
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadow → List<BoxShadow>
The shadow(s) of a dialog box.
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited