RadioButtonTheme class

Constructors

RadioButtonTheme({Widget selectedRadioButton = const DecoratedBox(decoration: BoxDecoration(shape: BoxShape.circle, color: Color.fromRGBO(64, 64, 64, 1.0), border: Border.fromBorderSide(BorderSide(color: Color.fromRGBO(150, 150, 150, 1.0))), boxShadow: [BoxShadow(color: Color.fromRGBO(0, 0, 0, 0.5), blurRadius: 2.0, offset: Offset(0.5, 1.0), spreadRadius: 1.0)]), child: FractionallySizedBox(widthFactor: 0.67, heightFactor: 0.67, child: DecoratedBox(decoration: BoxDecoration(shape: BoxShape.circle, boxShadow: [BoxShadow(color: Color.fromRGBO(24, 125, 192, 1.0)), BoxShadow(color: Color.fromRGBO(32, 175, 255, 1.0), spreadRadius: -2.0, blurRadius: 2.5, offset: Offset(-1.0, -1.0))]), child: FractionallySizedBox(widthFactor: 0.24, heightFactor: 0.24, alignment: Alignment(-0.35, -0.35), child: DecoratedBox(decoration: BoxDecoration(shape: BoxShape.circle, gradient: LinearGradient(colors: [Color.fromRGBO(255, 255, 255, 0.3), Color.fromRGBO(255, 255, 255, 0.25), Color.fromRGBO(255, 255, 255, 0.05)]))))))), Widget unselectedRadioButton = const DecoratedBox(decoration: BoxDecoration(shape: BoxShape.circle, color: Color.fromRGBO(52, 52, 52, 1.0), border: Border.fromBorderSide(BorderSide(color: Color.fromRGBO(82, 82, 82, 1.0))))), double spaceBetweenRadioButtonAndLabel = 12.0, TextStyle selectedRadioButtonLabelStyle = const TextStyle(color: Colors.white), TextStyle unselectedRadioButtonLabelStyle = const TextStyle(color: Color.fromRGBO(255, 255, 255, 0.5))})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedRadioButton → Widget
The widget to use as the selected radio button.
final
selectedRadioButtonLabelStyle → TextStyle
The text style of a selected radio buttons label.
final
spaceBetweenRadioButtonAndLabel → double
The space between a radio button and its label.
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
unselectedRadioButton → Widget
The widget to use as the unselected radio button.
final
unselectedRadioButtonLabelStyle → TextStyle
The text style of an unselected radio buttons label.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited