TabTheme class

Constructors

TabTheme({double minWidth = 94.0, double maxWidth = 192.0, BoxDecoration focusedTabBoxDecoration = const BoxDecoration(color: Color.fromRGBO(41, 43, 53, 1.0), border: GradientBoxBorder(gradient: LinearGradient(colors: [Color.fromRGBO(255, 255, 255, 0.2), Colors.transparent, Colors.transparent], begin: Alignment.topCenter, end: Alignment.bottomCenter), width: 1.0), borderRadius: BorderRadius.only(topLeft: Radius.circular(3.0), topRight: Radius.circular(3.0)), boxShadow: [BoxShadow(blurRadius: 16.0, color: Color.fromRGBO(0, 0, 0, 0.5))]), BoxDecoration unfocusedTabBoxDecoration = const BoxDecoration(color: Colors.transparent), double focusedTabAccentColorDecorationWidth = 3.0, BoxDecoration separatorBoxDecoration = const BoxDecoration(gradient: LinearGradient(begin: Alignment.topCenter, end: Alignment.bottomCenter, colors: [Color.fromRGBO(255, 255, 255, 0.0), Color.fromRGBO(255, 255, 255, 0.1), Color.fromRGBO(255, 255, 255, 0.0)])), BoxDecoration lightReflectionBoxDecoration = const BoxDecoration(borderRadius: BorderRadius.only(topLeft: Radius.circular(3.0), topRight: Radius.circular(3.0)), gradient: LinearGradient(begin: Alignment.topCenter, end: Alignment.bottomCenter, colors: [Color.fromRGBO(255, 255, 255, 0.3), Color.fromRGBO(255, 255, 255, 0.12), Color.fromRGBO(255, 255, 255, 0.1), Color.fromRGBO(255, 255, 255, 0.05), Color.fromRGBO(255, 255, 255, 0.02), Color.fromRGBO(255, 255, 255, 0.0)])), EdgeInsets iconPadding = const EdgeInsets.only(right: 4.0), double iconSize = 21.0, TextStyle textStyle = const TextStyle(color: Colors.white, fontSize: 12.0, fontWeight: FontWeight.w600), double unfocusedHoveredTabOpacity = 0.7, double unfocusedNotHoveredTabOpacity = 0.4, Duration unfocusedTabOpacityChangeDuration = const Duration(milliseconds: 150), double spaceAboveTabs = 4.0, EdgeInsets contentPadding = const EdgeInsets.all(8.0), Duration openingAnimationDuration = const Duration(milliseconds: 150), Curve openingAnimationCurve = Curves.ease})
const

Properties

contentPadding → EdgeInsets
The padding of the tabs' content.
final
focusedTabAccentColorDecorationWidth → double
The width of the decoration of the focused tab.
final
focusedTabBoxDecoration → BoxDecoration
The box decoration of the focused tab.
final
hashCode → int
The hash code for this object.
no setterinherited
iconPadding → EdgeInsets
The padding of the tabs' icons.
final
iconSize → double
The size of the tabs' icons.
final
lightReflectionBoxDecoration → BoxDecoration
The box decoration of the active tab's light reflection.
final
maxWidth → double
The maximal tab width.
final
minWidth → double
The minimal tab width.
final
openingAnimationCurve → Curve
The animation curve of the animation that plays when a new tab has been opened.
final
openingAnimationDuration → Duration
The duration of the animation that plays when a new tab has been opened.
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
separatorBoxDecoration → BoxDecoration
The width of the line that separates tabs.
final
spaceAboveTabs → double
The space above the tab bar.
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
textStyle → TextStyle
The text style of the tabs' text.
final
unfocusedHoveredTabOpacity → double
The opacity of unfocused tabs that are being hovered over.
final
unfocusedNotHoveredTabOpacity → double
The opacity of unfocused tabs that are not being hovered over.
final
unfocusedTabBoxDecoration → BoxDecoration
The box decoration of the unfocused tabs.
final
unfocusedTabOpacityChangeDuration → Duration
The duration of the opacity change animation that plays when an unfocused tab is hovered over.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited