ManualWidgetTesterThemeData class

Constructors

ManualWidgetTesterThemeData({TabTheme tabTheme = const TabTheme(), ButtonTheme buttonTheme = const ButtonTheme(), TextFieldTheme textFieldTheme = const TextFieldTheme(), ZoomControlsTheme zoomControlsTheme = const ZoomControlsTheme(), FoldableRegionTheme foldableRegionTheme = const FoldableRegionTheme(), CreateTestSessionDialogTheme createTestSessionDialogTheme = const CreateTestSessionDialogTheme(), TestSessionMenuItemTheme testSessionMenuItemTheme = const TestSessionMenuItemTheme(), EditColorButtonTheme editColorButtonTheme = const EditColorButtonTheme(), DialogTheme dialogTheme = const DialogTheme(), DoubleEditorTheme doubleEditorTheme = const DoubleEditorTheme(), BoolEditorTheme boolEditorTheme = const BoolEditorTheme(), CustomSettingHeadingTheme customSettingHeadingTheme = const CustomSettingHeadingTheme(), DragHandleTheme dragHandleTheme = const DragHandleTheme(), NoCustomSettingsMessageTheme noCustomSettingsMessageTheme = const NoCustomSettingsMessageTheme(), RadioButtonTheme radioButtonTheme = const RadioButtonTheme(), CloseButtonTheme closeButtonTheme = const CloseButtonTheme(), NoEditorMessageTheme noEditorMessageTheme = const NoEditorMessageTheme(), AppBarTheme appBarTheme = const AppBarTheme(), StringEditorTheme stringEditorTheme = const StringEditorTheme(), CreateTestSessionButtonTheme createTestSessionButtonTheme = const CreateTestSessionButtonTheme(), IconTheme iconTheme = const IconTheme(), CustomSettingsTheme customSettingsTheme = const CustomSettingsTheme(), WidgetTestSessionAreaTheme widgetTestSessionAreaTheme = const WidgetTestSessionAreaTheme(), GeneralTheme generalTheme = const GeneralTheme(), EditColorDialogTheme editColorDialogTheme = const EditColorDialogTheme()})
const

Properties

appBarTheme → AppBarTheme
The theme of the app bar.
final
boolEditorTheme → BoolEditorTheme
The boolean editor theme.
final
buttonTheme → ButtonTheme
The button theme.
final
closeButtonTheme → CloseButtonTheme
The close button theme.
final
createTestSessionButtonTheme → CreateTestSessionButtonTheme
The theme of the “create test session” button.
final
createTestSessionDialogTheme → CreateTestSessionDialogTheme
The theme of the “create test session” dialog
final
customSettingHeadingTheme → CustomSettingHeadingTheme
The custom settings heading theme.
final
customSettingsTheme → CustomSettingsTheme
The custom settings theme.
final
dialogTheme → DialogTheme
The dialog theme.
final
doubleEditorTheme → DoubleEditorTheme
The double editor theme.
final
dragHandleTheme → DragHandleTheme
The theme of the drag handle.
final
editColorButtonTheme → EditColorButtonTheme
The edit color button theme.
final
editColorDialogTheme → EditColorDialogTheme
The theme of the “edit color” dialog.
final
foldableRegionTheme → FoldableRegionTheme
The foldable region theme.
final
generalTheme → GeneralTheme
The “general” theme.
final
hashCode → int
The hash code for this object.
no setterinherited
iconTheme → IconTheme
The icon theme.
final
noCustomSettingsMessageTheme → NoCustomSettingsMessageTheme
The theme of the message that is displayed when a test session has no custom settings.
final
noEditorMessageTheme → NoEditorMessageTheme
The theme of the message that is displayed when no editor for a particular setting could be built.
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
radioButtonTheme → RadioButtonTheme
The radio button theme.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringEditorTheme → StringEditorTheme
The string editor theme.
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
tabTheme → TabTheme
The tab theme.
final
testSessionMenuItemTheme → TestSessionMenuItemTheme
The test session menu item theme.
final
textFieldTheme → TextFieldTheme
The text field theme.
final
widgetTestSessionAreaTheme → WidgetTestSessionAreaTheme
The widget test session area theme.
final
zoomControlsTheme → ZoomControlsTheme
The theme of the zoom controls.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited